=======
NSpider
=======

Overview
========

NSpider (NymphSpider) is a light multi-process web crawling and web scraping framework, used to
crawl websites and extract resource files from their pages. It can be used for
resources downloading and data collection.

Check the NSpider homepage at https://github.com/Nymphxyz/nspider for more information,

Requirements
============

* Python 3.6+
* Works on Linux(not sure), Windows, macOS(not sure)

Install
=======

The quick way::

    pip install nspider

Documentation
=============

Check details at https://github.com/Nymphxyz/nspider
